
import 'package:dio/dio.dart';
import 'package:flutter_easy_utils/src/api/APIMixin.dart';
import 'package:flutter_easy_utils/src/api/APIResponse.dart';


class APIs extends APIMixin {
  final context;

  APIs(this.context);

  Future<APIResponse> getData<T>(url, {token:false}) async {
    APIResponse apiResponse = APIResponse();

    try{
      Response response =  token ? await getWithToken(url) : await get(url);

      if (response == null) {
        apiResponse.error = "null response";
        return apiResponse;
      }

      Map responseJson = response.data;

      if (response.statusCode == 200 || response.statusCode == 201) {
        if (responseJson.containsKey("success")) {
          if (responseJson["success"] == true) {
            apiResponse.data = responseJson["data"];
          } else if (responseJson["success"] == false &&
              responseJson["validate"] == true) {
            apiResponse.error = validateError(context, responseJson);
          } else {
            apiResponse.error = falseSuccessError(context, responseJson);
          }
        } else {
          apiResponse.error = noSuccessError(context, responseJson);
        }
      } else {
        apiResponse.error = statusCodeError(context, response);
      }
    }catch(e){
      apiResponse.error = exceptionError(context, e);
    }

    return apiResponse;
  }

  Future<APIResponse> postData<T>(url, {data: const {} , token:false}) async {
    APIResponse apiResponse = APIResponse();
    try {
      var response =  token ? await postWithToken(url , data) : await post(url , data);

      if (response == null) {
        apiResponse.error = "null response";
        return apiResponse;
      }

      Map responseJson = response.data;

      if (response.statusCode == 200 || response.statusCode == 201) {
        if (responseJson.containsKey("success")) {
          if (responseJson["success"] == true) {
            apiResponse.data = responseJson["data"];
          } else if (responseJson["success"] == false &&
              responseJson["validate"] == true) {
            apiResponse.error = validateError(context, responseJson);
          } else {
            apiResponse.error = falseSuccessError(context, responseJson);
          }
        } else {
          apiResponse.error = noSuccessError(context, responseJson);
        }
      } else {
        apiResponse.error = statusCodeError(context, response);
      }
    } catch (e) {
      apiResponse.error = exceptionError(context, e);
    }

    return apiResponse;
  }
}
